Ocyan plugin Oscar Shipping Plugin
==================================

Installation
------------
Add `ocyan.plugin.oscar_shipping` to your projects dependencies.


Description
-----------
With the Shipping plugin you can create/add shipping methods in the django-admin to all countries or a specific one.
If required, you can set a another tax rate for shipping. See “Hidden options” below how.


There are a few methods you can choose from:
* Free shipping.
* Weightbased shipping:
	* You can set specific prices per kilogram.
	* You can also set a default value if products in your basket do not have kilograms set.
* Charged shipping:
	* This is a fixed amount for shipping, which you can set per item in your basket or your entire basket. You can also set a minimal required amount for the shipping method to be free under the “Free shipping” field.
* Paid shipping first:
	* If this shipping method is selected, the paid shopping methods will be first displayed to the user.


Hidden options
--------------
The shipping plugin has the hidden configuration option shipping_tax_rate which can be used to override the shipping tax rate if a customer wants the tax rate to be overridden. This option is not shown in fendergui.


Configuration
-------------
* enable_free_shipping: 
	* If this option is set to true, a free shipping method is automatically shown on the checkout page.
	* You can set this option to true or false.
	* This shipping option is as default true.

* enable_weightbased_shipping:
	* If this options is true, a weight based shipping option is available to customers.
	* You can set this option to true or false.
	* This shipping option is as default false.

* enable_charged_shipping:
	* If this options is true, shipping can be charged per order/item.
	* You can set this option to true or false.
	* This shipping option is as default false.

* paid_shipping_first:
	* If this option is true, the order or priority of shipping is reversed.
	* You can set this option to true or false.
	* This shipping option is as default false.

* enable_product_based_shipping:
    * If this option is true, product based shipping will be available to our clients.
    * This option defaults to false.

* shipping_cost_attribute:
    * You can change the attribute that's used to look up a product shipping price
    * The default attribute code that's being used is: shipping_cost

For example:

```json
    "oscar_shipping": {
      "enable_free_shipping": true,
      "enable_weightbased_shipping": false,
      "enable_charged_shipping": false,
      "paid_shipping_first": true,
      "enable_product_based_shipping": true,
      "shipping_cost_attribute": "shipping_cost"
    },
```

